<?php

namespace Emulator\Network\Game\Sessions;

use Emulator\Encoding\ByteEncoding;
use Emulator\Messages\Outgoing\IMessageComposer;
use Emulator\Messages\Outgoing\ServerMessage;
use Ratchet\RFC6455\Messaging\Frame;
use Ratchet\RFC6455\Messaging\Message;
use Ratchet\WebSocket\WsConnection;

readonly class Session {
    private WsConnection $connection;

    public function __construct(WsConnection $connection) {
        $this->connection = $connection;
    }

    public function sendComposer(IMessageComposer $composer): void {
        $headerData = pack('n', 2491);
        $length = strlen($headerData);
        $lengthData = pack('N', $length);
        $binaryMessage = $lengthData . $headerData;
        $frame = new Frame($binaryMessage, true, Frame::OP_BINARY);
        $this->connection->send($frame);
    }

    function encode($text) {
        $b1 = 0x80 | (0x1 & 0x0f);
        $length = strlen($text);
        if ($length <= 125)
            $header = pack('CC', $b1, $length);
        elseif($length > 125 && $length < 65536)
            $header = pack('CCn', $b1, 126, $length);
        elseif($length >= 65536)
            $header = pack('CCNN', $b1, 127, $length);

        return $header.$text;
    }

}